<?php

/**
 * @file
 *   drush integration for easychart.
 */
// source --> http://drupal.stackexchange.com/questions/51701/automatically-downloading-libraries-for-a-module
/**
 * Implements hook_drush_command().
 *
 * In this hook, you specify which commands your
 * drush module makes available, what it does and
 * description.
 *
 * Notice how this structure closely resembles how
 * you define menu hooks.
 *
 * @See drush_parse_command() for a list of recognized keys.
 *
 * @return
 *   An associative array describing your command(s).
 */
function easychart_drush_command()
{
    $items = array();

    $items['dl-easychart-dependencies'] = array(
        'callback' => 'easychart_drush_js_dependencies_download',
        'description' => dt('Downloads the required javascript dependencies.'),
        'bootstrap' => DRUSH_BOOTSTRAP_DRUSH,
        'aliases' => array('bubbles-for-me'),
    );


    return $items;
}

/**
 * Implements hook_drush_help().
 *
 * This function is called whenever a drush user calls
 * 'drush help <name-of-your-command>'
 *
 * @param
 *   A string with the help section (prepend with 'drush:')
 *
 * @return
 *   A string with the help text for your command.
 */
// todo
function easychart_drush_help($section)
{
    switch ($section) {
        case 'drush:dl-easychart-dependencies':
            return dt("Downloads the required javascript dependencies: the Easychart javascript plugin and the Highcharts Library.");
    }
}

/**
 * Example drush command callback.
 *
 * This is where the action takes place.
 *
 * In this function, all of Drupals API is (usually) available, including
 * any functions you have added in your own modules/themes.
 *
 * To print something to the terminal window, use drush_print().
 *
 */
function easychart_drush_js_dependencies_download()
{
    if (module_exists('libraries')) {
        $path = 'sites/all/libraries';

        // Create the path if it does not exist.
        if (!is_dir($path)) {
            drush_op('mkdir', $path);
            $message = dt('Directory @path was created', array('@path' => $path));
            drush_log($message, 'notice');
            drush_print($message);
        } else {
            $message = dt('Directory @path already exists', array('@path' => $path));
            drush_log($message, 'notice');
            drush_print($message);
        }
    } else {
        // show error --> libraries required
    }

    drush_op('chdir', $path);

    drush_log(dt('starting download of javascript dependencies...'),'notice');

    if (!is_dir('easychart')) {
        if (drush_shell_exec('curl -L https://github.com/bestuurszaken/easychart/tarball/44456b33b809922ba1dcebdb9d446274a021d16f | tar zx')) {
            if (drush_shell_exec('mv bestuurszaken-easychart-44456b3 easychart')) {
                if (drush_shell_exec('rm bestuurszaken-easychart-44456b3')) {
                    drush_log(dt('Easychart javascript plugin downloaded and unpacked'), 'ok');
                }
            }
        } else {
            drush_log(dt('Drush was unable to download the Easychart plugin'), 'error');
        }
    } else {
        drush_log(dt('Easychart-plugin already present.'), 'error');
    }

    if (!is_dir('highcharts')) {
        if (drush_shell_exec('curl -O http://code.highcharts.com/zips/Highcharts-4.1.9.zip')) {
            if (drush_shell_exec('unzip Highcharts-4.1.9.zip -d highcharts')) {
                if (drush_shell_exec('rm Highcharts-4.1.9.zip')) {
                    drush_log(dt('Highcharts Library downloaded and unpacked'), 'ok');
                }
            } else {
                drush_log(dt('Drush was unable to unzip the Highcharts zip-package'), 'error');
            }
        } else {
            drush_log(dt('Drush was unable to download the Highcharts library'), 'error');
        }
    } else {
        drush_log(dt('The Highcharts library is already present.'), 'error');
    }
}